import { Component, Input, forwardRef, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { InputTextModule } from 'primeng/inputtext';
import { DropdownModule } from 'primeng/dropdown';
import { CheckboxModule } from 'primeng/checkbox';
import { RadioButtonModule } from 'primeng/radiobutton';
import { InputTextareaModule } from 'primeng/inputtextarea';
import { AutoCompleteModule } from 'primeng/autocomplete';
import { CalendarModule } from 'primeng/calendar';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const EXPANDED_INPUT_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => InputComponent),
    multi: true,
};
class InputComponent {
    constructor() {
        this.isDisabled = false;
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        this.value = /** @type {?} */ (obj);
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onBlur = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    change($event) {
        this.onChange(this.value);
    }
}
InputComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-input',
                template: `<div class="form-group">
    <label>{{config?.label}}</label>
    <input type="text" class="form-control" pInputText [(ngModel)]="value" [disabled]="isDisabled" (blur)="onBlur()" (change)="change($event)"
    />
</div>`,
                styles: [``],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR],
            },] },
];
/** @nocollapse */
InputComponent.ctorParameters = () => [];
InputComponent.propDecorators = {
    "config": [{ type: Input },],
};

// interface inputAttributeConfig {
//   accept?: string;
//   alt?: string;
//   autocomplete?: string;
//   autofocus?: string;
//   checked?: string;
//   dirname?: string;
//   disabled?: string;
//   form?: string;
//   formaction?: string;
//   formenctype?: string;
//   formmethod?: string;
//   formnovalidate?: string;
//   formtarget?: string;
//   height?: string;
//   list?: string;
//   max?: string;
//   maxlength?: string;
//   min?: string;
//   multiple?: string;
//   name?: string;
//   pattern?: string;
//   placeholder?: string;
//   readonly?: string;
//   required?: string;
//   size?: string;
//   src?: string;
//   step?: string;
//   type?: string;
//   value?: string;
//   width?: string;
// }

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const EXPANDED_INPUT_VALUE_ACCESSOR$1 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => DropdownComponent),
    multi: true,
};
class DropdownComponent {
    constructor() {
        this.isDisabled = false;
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        this.value = obj;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onBlur = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    change($event) {
        this.onChange(this.value);
    }
}
DropdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-dropdown',
                template: `<div class="form-group">
  <label>{{config?.label}}</label>
  <p-dropdown [ngClass]="'form-control'" [options]="config.options" [(ngModel)]="value" (onBlur)="onBlur()" (onChange)="change($event)"
    [filter]="config.allowFilter" filterBy="label">
  </p-dropdown>
</div>`,
                styles: [``],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$1],
            },] },
];
/** @nocollapse */
DropdownComponent.ctorParameters = () => [];
DropdownComponent.propDecorators = {
    "config": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const EXPANDED_INPUT_VALUE_ACCESSOR$2 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => CheckboxComponent),
    multi: true,
};
class CheckboxComponent {
    constructor() {
        this.selectedItems = [];
        this.isDisabled = false;
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        if (!!obj) {
            this.selectedItems = [...obj];
        }
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onBlur = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!(this.config && this.config.options && this.config.options.length)) {
            this.config = Object.assign({ options: [] }, this.config);
        }
        this.config.options = this.config.options.map(i => ({
            name: this.formatControlName(i.label),
            option: i
        }));
    }
    /**
     * @param {?} str
     * @return {?}
     */
    formatControlName(str) {
        return 'fc_' + str;
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    change($event) {
        this.onChange(this.selectedItems);
    }
}
CheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-checkbox',
                template: `  <h6>{{config.label}}</h6>
  <ng-template ngFor let-item [ngForOf]="config.options" let-index>
    <div class="form-check" [ngClass]="{'form-check-inline':true}">
      <label class="form-check-label">
        <p-checkbox name="{{item.fcName}}" value="{{item.option.value}}" label="{{item.option.label}}" [(ngModel)]="selectedItems" (onChange)="change($event)"></p-checkbox>
      </label>
    </div>
  </ng-template>`,
                styles: [``],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$2],
            },] },
];
/** @nocollapse */
CheckboxComponent.ctorParameters = () => [];
CheckboxComponent.propDecorators = {
    "config": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const EXPANDED_INPUT_VALUE_ACCESSOR$3 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => RadiobuttonComponent),
    multi: true,
};
class RadiobuttonComponent {
    constructor() {
        this.isDisabled = false;
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        this.value = obj;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onBlur = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!(this.config && this.config.options && this.config.options.length)) {
            this.config = Object.assign({ options: [] }, this.config);
        }
    }
    /**
     * @param {?} selectedItem
     * @return {?}
     */
    change(selectedItem) {
        this.onChange(selectedItem);
    }
}
RadiobuttonComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-radiobutton',
                template: `<h6>{{config.label}}</h6>
<ng-template ngFor let-item [ngForOf]="config.options" let-index>
  <div class="form-check" [ngClass]="{'form-check-inline':true}">
    <label class="form-check-label">
        <p-radioButton [disabled]="isDisabled" name="{{config.label}}" label="{{item.label}}" 
        value="{{item.value}}" [(ngModel)]="value" (onClick)="change(item.value)" ></p-radioButton>
    </label>
  </div>
</ng-template>`,
                styles: [``],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$3],
            },] },
];
/** @nocollapse */
RadiobuttonComponent.ctorParameters = () => [];
RadiobuttonComponent.propDecorators = {
    "config": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const EXPANDED_INPUT_VALUE_ACCESSOR$4 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => TextareaComponent),
    multi: true,
};
class TextareaComponent {
    constructor() {
        this.isDisabled = false;
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        this.value = /** @type {?} */ (obj);
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onBlur = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    change($event) {
        this.onChange(this.value);
    }
}
TextareaComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-textarea',
                template: `<div class="form-group">
    <label>{{config?.label}}</label>
    <textarea [rows]="5" [cols]="30" [(ngModel)]="value" (change)="change($event)" pInputTextarea autoResize="true" [disabled]="isDisabled"></textarea>
</div>`,
                styles: [``],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$4],
            },] },
];
/** @nocollapse */
TextareaComponent.ctorParameters = () => [];
TextareaComponent.propDecorators = {
    "config": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const EXPANDED_INPUT_VALUE_ACCESSOR$5 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => AutocompleteComponent),
    multi: true,
};
class AutocompleteComponent {
    constructor() {
        this.isDisabled = false;
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        this.value = obj;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onBlur = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.config.results.subscribe(d => {
            this.results = [...d];
        });
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    change($event) {
        this.onChange(this.value);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    search(event) {
        this.config.onSearch(event.query);
    }
}
AutocompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-autocomplete',
                template: `<div class="form-group">
    <label>{{config?.label}}</label>
    <p-autoComplete [(ngModel)]="value" [suggestions]="results" (completeMethod)="search($event)" [multiple]="config.isMultiple"
    (onSelect)="change($event)" (onUnselect)="change($event)"></p-autoComplete>
</div>`,
                styles: [``],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$5],
            },] },
];
/** @nocollapse */
AutocompleteComponent.ctorParameters = () => [];
AutocompleteComponent.propDecorators = {
    "config": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const EXPANDED_INPUT_VALUE_ACCESSOR$6 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => DateComponent),
    multi: true,
};
class DateComponent {
    constructor() {
        this.isDisabled = false;
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        this.value = obj;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.onChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this.onBlur = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onSelect($event) {
        this.onChange(this.value);
    }
}
DateComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-date',
                template: `<div class="form-group">
    <label>{{config?.label}}</label>
    <p-calendar [(ngModel)]="value"  (onBlur)="onBlur" (onSelect)="onSelect($event)"></p-calendar>
</div>

<!-- dateFormat="config.dateFormat"
d - day of month (no leading zero)
dd - day of month (two digit)
o - day of the year (no leading zeros)
oo - day of the year (three digit)
D - day name short
DD - day name long
m - month of year (no leading zero)
mm - month of year (two digit)
M - month name short
MM - month name long
y - year (two digit)
yy - year (four digit)
@ - Unix timestamp (ms since 01/01/1970)
! - Windows ticks (100ns since 01/01/0001)
'...' - literal text
'' - single quote
anything else - literal text 
-->`,
                styles: [``],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$6],
            },] },
];
/** @nocollapse */
DateComponent.ctorParameters = () => [];
DateComponent.propDecorators = {
    "config": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BlenderUiModule {
}
BlenderUiModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    InputTextModule,
                    DropdownModule,
                    CheckboxModule,
                    RadioButtonModule,
                    InputTextareaModule,
                    AutoCompleteModule,
                    CalendarModule,
                    BrowserAnimationsModule
                ],
                declarations: [InputComponent, DropdownComponent, CheckboxComponent, RadiobuttonComponent, TextareaComponent, AutocompleteComponent, DateComponent],
                exports: [InputComponent, DropdownComponent, CheckboxComponent, RadiobuttonComponent, TextareaComponent, AutocompleteComponent, DateComponent]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { BlenderUiModule, AutocompleteComponent as ɵl, EXPANDED_INPUT_VALUE_ACCESSOR$5 as ɵk, CheckboxComponent as ɵf, EXPANDED_INPUT_VALUE_ACCESSOR$2 as ɵe, DateComponent as ɵn, EXPANDED_INPUT_VALUE_ACCESSOR$6 as ɵm, DropdownComponent as ɵd, EXPANDED_INPUT_VALUE_ACCESSOR$1 as ɵc, EXPANDED_INPUT_VALUE_ACCESSOR as ɵa, InputComponent as ɵb, EXPANDED_INPUT_VALUE_ACCESSOR$3 as ɵg, RadiobuttonComponent as ɵh, EXPANDED_INPUT_VALUE_ACCESSOR$4 as ɵi, TextareaComponent as ɵj };
//# sourceMappingURL=blender-ui.js.map
