import { __spread } from 'tslib';
import { Component, Input, forwardRef, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { InputTextModule } from 'primeng/inputtext';
import { DropdownModule } from 'primeng/dropdown';
import { CheckboxModule } from 'primeng/checkbox';
import { RadioButtonModule } from 'primeng/radiobutton';
import { InputTextareaModule } from 'primeng/inputtextarea';
import { AutoCompleteModule } from 'primeng/autocomplete';
import { CalendarModule } from 'primeng/calendar';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

var EXPANDED_INPUT_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return InputComponent; }),
    multi: true,
};
var InputComponent = /** @class */ (function () {
    function InputComponent() {
        this.isDisabled = false;
    }
    InputComponent.prototype.writeValue = function (obj) {
        this.value = (obj);
    };
    InputComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    InputComponent.prototype.registerOnTouched = function (fn) {
        this.onBlur = fn;
    };
    InputComponent.prototype.setDisabledState = function (isDisabled) {
        this.isDisabled = isDisabled;
    };
    InputComponent.prototype.ngOnInit = function () {
    };
    InputComponent.prototype.change = function ($event) {
        this.onChange(this.value);
    };
    return InputComponent;
}());
InputComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-input',
                template: "<div class=\"form-group\">\n    <label>{{config?.label}}</label>\n    <input type=\"text\" class=\"form-control\" pInputText [(ngModel)]=\"value\" [disabled]=\"isDisabled\" (blur)=\"onBlur()\" (change)=\"change($event)\"\n    />\n</div>",
                styles: [""],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR],
            },] },
];
InputComponent.ctorParameters = function () { return []; };
InputComponent.propDecorators = {
    "config": [{ type: Input },],
};
var EXPANDED_INPUT_VALUE_ACCESSOR$1 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return DropdownComponent; }),
    multi: true,
};
var DropdownComponent = /** @class */ (function () {
    function DropdownComponent() {
        this.isDisabled = false;
    }
    DropdownComponent.prototype.writeValue = function (obj) {
        this.value = obj;
    };
    DropdownComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    DropdownComponent.prototype.registerOnTouched = function (fn) {
        this.onBlur = fn;
    };
    DropdownComponent.prototype.setDisabledState = function (isDisabled) {
        this.isDisabled = isDisabled;
    };
    DropdownComponent.prototype.ngOnInit = function () {
    };
    DropdownComponent.prototype.change = function ($event) {
        this.onChange(this.value);
    };
    return DropdownComponent;
}());
DropdownComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-dropdown',
                template: "<div class=\"form-group\">\n  <label>{{config?.label}}</label>\n  <p-dropdown [ngClass]=\"'form-control'\" [options]=\"config.options\" [(ngModel)]=\"value\" (onBlur)=\"onBlur()\" (onChange)=\"change($event)\"\n    [filter]=\"config.allowFilter\" filterBy=\"label\">\n  </p-dropdown>\n</div>",
                styles: [""],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$1],
            },] },
];
DropdownComponent.ctorParameters = function () { return []; };
DropdownComponent.propDecorators = {
    "config": [{ type: Input },],
};
var EXPANDED_INPUT_VALUE_ACCESSOR$2 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return CheckboxComponent; }),
    multi: true,
};
var CheckboxComponent = /** @class */ (function () {
    function CheckboxComponent() {
        this.selectedItems = [];
        this.isDisabled = false;
    }
    CheckboxComponent.prototype.writeValue = function (obj) {
        if (!!obj) {
            this.selectedItems = __spread(obj);
        }
    };
    CheckboxComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    CheckboxComponent.prototype.registerOnTouched = function (fn) {
        this.onBlur = fn;
    };
    CheckboxComponent.prototype.setDisabledState = function (isDisabled) {
        this.isDisabled = isDisabled;
    };
    CheckboxComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (!(this.config && this.config.options && this.config.options.length)) {
            this.config = Object.assign({ options: [] }, this.config);
        }
        this.config.options = this.config.options.map(function (i) { return ({
            name: _this.formatControlName(i.label),
            option: i
        }); });
    };
    CheckboxComponent.prototype.formatControlName = function (str) {
        return 'fc_' + str;
    };
    CheckboxComponent.prototype.change = function ($event) {
        this.onChange(this.selectedItems);
    };
    return CheckboxComponent;
}());
CheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-checkbox',
                template: "  <h6>{{config.label}}</h6>\n  <ng-template ngFor let-item [ngForOf]=\"config.options\" let-index>\n    <div class=\"form-check\" [ngClass]=\"{'form-check-inline':true}\">\n      <label class=\"form-check-label\">\n        <p-checkbox name=\"{{item.fcName}}\" value=\"{{item.option.value}}\" label=\"{{item.option.label}}\" [(ngModel)]=\"selectedItems\" (onChange)=\"change($event)\"></p-checkbox>\n      </label>\n    </div>\n  </ng-template>",
                styles: [""],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$2],
            },] },
];
CheckboxComponent.ctorParameters = function () { return []; };
CheckboxComponent.propDecorators = {
    "config": [{ type: Input },],
};
var EXPANDED_INPUT_VALUE_ACCESSOR$3 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return RadiobuttonComponent; }),
    multi: true,
};
var RadiobuttonComponent = /** @class */ (function () {
    function RadiobuttonComponent() {
        this.isDisabled = false;
    }
    RadiobuttonComponent.prototype.writeValue = function (obj) {
        this.value = obj;
    };
    RadiobuttonComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    RadiobuttonComponent.prototype.registerOnTouched = function (fn) {
        this.onBlur = fn;
    };
    RadiobuttonComponent.prototype.setDisabledState = function (isDisabled) {
        this.isDisabled = isDisabled;
    };
    RadiobuttonComponent.prototype.ngOnInit = function () {
        if (!(this.config && this.config.options && this.config.options.length)) {
            this.config = Object.assign({ options: [] }, this.config);
        }
    };
    RadiobuttonComponent.prototype.change = function (selectedItem) {
        this.onChange(selectedItem);
    };
    return RadiobuttonComponent;
}());
RadiobuttonComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-radiobutton',
                template: "<h6>{{config.label}}</h6>\n<ng-template ngFor let-item [ngForOf]=\"config.options\" let-index>\n  <div class=\"form-check\" [ngClass]=\"{'form-check-inline':true}\">\n    <label class=\"form-check-label\">\n        <p-radioButton [disabled]=\"isDisabled\" name=\"{{config.label}}\" label=\"{{item.label}}\" \n        value=\"{{item.value}}\" [(ngModel)]=\"value\" (onClick)=\"change(item.value)\" ></p-radioButton>\n    </label>\n  </div>\n</ng-template>",
                styles: [""],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$3],
            },] },
];
RadiobuttonComponent.ctorParameters = function () { return []; };
RadiobuttonComponent.propDecorators = {
    "config": [{ type: Input },],
};
var EXPANDED_INPUT_VALUE_ACCESSOR$4 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return TextareaComponent; }),
    multi: true,
};
var TextareaComponent = /** @class */ (function () {
    function TextareaComponent() {
        this.isDisabled = false;
    }
    TextareaComponent.prototype.writeValue = function (obj) {
        this.value = (obj);
    };
    TextareaComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    TextareaComponent.prototype.registerOnTouched = function (fn) {
        this.onBlur = fn;
    };
    TextareaComponent.prototype.setDisabledState = function (isDisabled) {
        this.isDisabled = isDisabled;
    };
    TextareaComponent.prototype.ngOnInit = function () {
    };
    TextareaComponent.prototype.change = function ($event) {
        this.onChange(this.value);
    };
    return TextareaComponent;
}());
TextareaComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-textarea',
                template: "<div class=\"form-group\">\n    <label>{{config?.label}}</label>\n    <textarea [rows]=\"5\" [cols]=\"30\" [(ngModel)]=\"value\" (change)=\"change($event)\" pInputTextarea autoResize=\"true\" [disabled]=\"isDisabled\"></textarea>\n</div>",
                styles: [""],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$4],
            },] },
];
TextareaComponent.ctorParameters = function () { return []; };
TextareaComponent.propDecorators = {
    "config": [{ type: Input },],
};
var EXPANDED_INPUT_VALUE_ACCESSOR$5 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return AutocompleteComponent; }),
    multi: true,
};
var AutocompleteComponent = /** @class */ (function () {
    function AutocompleteComponent() {
        this.isDisabled = false;
    }
    AutocompleteComponent.prototype.writeValue = function (obj) {
        this.value = obj;
    };
    AutocompleteComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    AutocompleteComponent.prototype.registerOnTouched = function (fn) {
        this.onBlur = fn;
    };
    AutocompleteComponent.prototype.setDisabledState = function (isDisabled) {
        this.isDisabled = isDisabled;
    };
    AutocompleteComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.config.results.subscribe(function (d) {
            _this.results = __spread(d);
        });
    };
    AutocompleteComponent.prototype.change = function ($event) {
        this.onChange(this.value);
    };
    AutocompleteComponent.prototype.search = function (event) {
        this.config.onSearch(event.query);
    };
    return AutocompleteComponent;
}());
AutocompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-autocomplete',
                template: "<div class=\"form-group\">\n    <label>{{config?.label}}</label>\n    <p-autoComplete [(ngModel)]=\"value\" [suggestions]=\"results\" (completeMethod)=\"search($event)\" [multiple]=\"config.isMultiple\"\n    (onSelect)=\"change($event)\" (onUnselect)=\"change($event)\"></p-autoComplete>\n</div>",
                styles: [""],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$5],
            },] },
];
AutocompleteComponent.ctorParameters = function () { return []; };
AutocompleteComponent.propDecorators = {
    "config": [{ type: Input },],
};
var EXPANDED_INPUT_VALUE_ACCESSOR$6 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(function () { return DateComponent; }),
    multi: true,
};
var DateComponent = /** @class */ (function () {
    function DateComponent() {
        this.isDisabled = false;
    }
    DateComponent.prototype.writeValue = function (obj) {
        this.value = obj;
    };
    DateComponent.prototype.registerOnChange = function (fn) {
        this.onChange = fn;
    };
    DateComponent.prototype.registerOnTouched = function (fn) {
        this.onBlur = fn;
    };
    DateComponent.prototype.setDisabledState = function (isDisabled) {
        this.isDisabled = isDisabled;
    };
    DateComponent.prototype.ngOnInit = function () {
    };
    DateComponent.prototype.onSelect = function ($event) {
        this.onChange(this.value);
    };
    return DateComponent;
}());
DateComponent.decorators = [
    { type: Component, args: [{
                selector: 'b-date',
                template: "<div class=\"form-group\">\n    <label>{{config?.label}}</label>\n    <p-calendar [(ngModel)]=\"value\"  (onBlur)=\"onBlur\" (onSelect)=\"onSelect($event)\"></p-calendar>\n</div>\n\n<!-- dateFormat=\"config.dateFormat\"\nd - day of month (no leading zero)\ndd - day of month (two digit)\no - day of the year (no leading zeros)\noo - day of the year (three digit)\nD - day name short\nDD - day name long\nm - month of year (no leading zero)\nmm - month of year (two digit)\nM - month name short\nMM - month name long\ny - year (two digit)\nyy - year (four digit)\n@ - Unix timestamp (ms since 01/01/1970)\n! - Windows ticks (100ns since 01/01/0001)\n'...' - literal text\n'' - single quote\nanything else - literal text \n-->",
                styles: [""],
                providers: [EXPANDED_INPUT_VALUE_ACCESSOR$6],
            },] },
];
DateComponent.ctorParameters = function () { return []; };
DateComponent.propDecorators = {
    "config": [{ type: Input },],
};
var BlenderUiModule = /** @class */ (function () {
    function BlenderUiModule() {
    }
    return BlenderUiModule;
}());
BlenderUiModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    InputTextModule,
                    DropdownModule,
                    CheckboxModule,
                    RadioButtonModule,
                    InputTextareaModule,
                    AutoCompleteModule,
                    CalendarModule,
                    BrowserAnimationsModule
                ],
                declarations: [InputComponent, DropdownComponent, CheckboxComponent, RadiobuttonComponent, TextareaComponent, AutocompleteComponent, DateComponent],
                exports: [InputComponent, DropdownComponent, CheckboxComponent, RadiobuttonComponent, TextareaComponent, AutocompleteComponent, DateComponent]
            },] },
];

export { BlenderUiModule, AutocompleteComponent as ɵl, EXPANDED_INPUT_VALUE_ACCESSOR$5 as ɵk, CheckboxComponent as ɵf, EXPANDED_INPUT_VALUE_ACCESSOR$2 as ɵe, DateComponent as ɵn, EXPANDED_INPUT_VALUE_ACCESSOR$6 as ɵm, DropdownComponent as ɵd, EXPANDED_INPUT_VALUE_ACCESSOR$1 as ɵc, EXPANDED_INPUT_VALUE_ACCESSOR as ɵa, InputComponent as ɵb, EXPANDED_INPUT_VALUE_ACCESSOR$3 as ɵg, RadiobuttonComponent as ɵh, EXPANDED_INPUT_VALUE_ACCESSOR$4 as ɵi, TextareaComponent as ɵj };
//# sourceMappingURL=blender-ui.js.map
